@@ -23,7 +23,8 @@ class Bank:
         """
         self.config = config
         if self.config.get("env") == "sandbox":
-            self.host = "https://developer.co-opbank.co.ke:8243"
+            self.host = "https://developer.co-opbank.co.ke:8280"
+            # self.host = "https://developer.co-opbank.co.ke:8243"
         else:
             self.host = "https://developer.co-opbank.co.ke:8280"
 
@@ -31,13 +32,21 @@ class Bank:
     def token(self):
         """Return the access token after authentication."""
         authorization = base64.b64encode(
-            self.config.get("consumerKey") + ":" +
-            self.config.get("consumerSecret")
+            bytes(
+                self.config.get("consumerKey")
+                + ":"
+                + self.config.get("consumerSecret"),
+                "utf8",
+            )
         )
         url = self.host + "/token"
         payload = {"grant_type": "client_credentials"}
         headers = {
             "Authorization": f"Basic {authorization}",
         }
-        response = requests.post(url, data=payload, headers=headers)
-        return response.json().get("access_token")
+        response = requests.post(
+            url, data=payload, headers=headers, verify=False)
+        try:
+            return response.json().get("access_token")
+        except Exception:
+            return response
