@@ -62,11 +62,11 @@ class PesaLinkToAccount(bank.Bank):
             "Content-Type": "application/json",
             "Authorization": f"Bearer {token}",
         }
-        response = requests.post(url, headers=headers, data=payload)
+        response = requests.post(url, headers=headers, data=payload,verify=False)
         if callback is not None:
             return callback(response)
         else:
-            return response.json()
+            return response
 
 
 class PesaLinkToPhone(bank.Bank):
@@ -125,4 +125,4 @@ class PesaLinkToPhone(bank.Bank):
         if callback is not None:
             return callback(response)
         else:
-            return response.json()
+            return response
