@@ -16,8 +16,9 @@ class TransactionStatus(bank.Bank):
             "Content-Type": "application/json",
             "Authorization": f"Bearer {token}",
         }
-        response = requests.post(url, headers=headers, data=payload)
+        response = requests.post(url, headers=headers,
+                                 data=payload, verify=False)
         if callback is not None:
             return callback(response)
         else:
-            return response.json()
+            return response
